@@ -739,7 +739,7 @@ my %flags = (
 sub generate_core_flags {
     # access (read, if set is true then write as well; if postset true then
     #         read first and write new value after that)
-    # to piddle's state
+    # to ndarray's state
     foreach my $name ( sort keys %flags ) {
         my $flag = "PDL_" . ($flags{$name}{FLAG} || uc($name));
         if ( $flags{$name}{set} ) {
@@ -798,12 +798,7 @@ sub generate_badval_init {
   for my $type (PDL::Types::types()) {
     my $typename = $type->shortctype;
     my $bval = $type->defbval;
-    if ($PDL::Config{BADVAL_USENAN} && $type->usenan) {
-      # note: no defaults if usenan
-      print "\tPDL.bvals.$typename = PDL.NaN_$type;\n"; #Core NaN value
-    } else {
-      print "\tPDL.bvals.$typename = PDL.bvals.default_$typename = $bval;\n";
-    }
+    print "\tPDL.bvals.$typename = PDL.bvals.default_$typename = $bval;\n";
   }
 }
 
@@ -825,6 +820,7 @@ sub got_complex_version {
     return $got_complex_cache{$name} if defined $got_complex_cache{$name};
     my $args = join ',', ('(double complex)1') x $params;
     $got_complex_cache{$name} = Devel::CheckLib::check_lib(
+        ($Config{gccversion} ? (ccflags => '-O0') : ()), # stop GCC optimising test code away
         lib => 'm',
         header => 'complex.h',
         function => sprintf('double num; num = creal(c%s(%s)); return 0;', $name, $args),
