@@ -43,13 +43,16 @@ use vars qw/$VERSION %EXPORT_TAGS %DEF_SYNS @ISA/;
 
 require Exporter;
 
-$VERSION = '0.90';
+# difference to 0.91 is that added CENTRE/CENTER as default
+# synonymns (patch by Diab Jerius [ #469110 ])
+our $VERSION = '0.92';
+$VERSION = eval $VERSION;
 
 @ISA = qw(Exporter);
 
 %EXPORT_TAGS = (
 		'Func' => [qw/
-			   parse
+			   parse iparse ifhref
 			   /]
 	       );
 
@@ -57,10 +60,27 @@ Exporter::export_tags('Func');
 
 # List of default synonyms
 %DEF_SYNS = (
-	     COLOR => 'COLOUR',
-	     COLOUR => 'COLOR'
+	     COLOR  => 'COLOUR',
+	     COLOUR => 'COLOR',
+	     CENTER => 'CENTRE',
+	     CENTRE => 'CENTER',
 	    );
 
+my $default = {
+	       WarnOnMissing => 1,
+	       FullOptions => 1,
+	       DEBUG => 0,
+	      };
+
+=head1 Utility functions
+
+=head2 ifhref
+
+  parse({Ext => 'TIF', ifhref($opt)});
+
+just return the argument if it is a hashref otherwise return
+an empty hashref. Useful in conjunction with parse to return
+just the default values if argument is not a hash ref
 
 =head1 NON-OO INTERFACE
 
@@ -72,21 +92,33 @@ These routines are exported into the callers namespace by default.
 =item parse( \%defaults, \%user_options)
 
 This will parse user options by using the defaults.  The following
-settings are used for parsing: The options can be case-insensitive, a
-default synonym table is consulted (currently just contains a synonym
-for COLOUR), minimum-matching is turned on, translation of values is
-not performed.
+settings are used for parsing: The options are case-sensitive, a
+default synonym table is consulted (see L</Default Synonyms>),
+minimum-matching is turned on, and translation of values is not performed.
 
 A hash (not hash reference) containing the processed options is returned.
 
   %options = parse( { LINE => 1, COLOUR => 'red'}, { COLOR => 'blue'});
 
+=item iparse( \%defaults, \%user_options)
+
+Same as C<parse> but matching is case insensitive
+
 =cut
 
-sub parse {
+sub ifhref {
+  my ($href) = @_;
+  return defined $href && ref $href eq 'HASH' ? $href : {};
+}
 
-   croak 'Usage: parse( \%defaults, \%user )' if scalar(@_) != 2;
+sub parse { return _parse(1,@_) }
+sub iparse { return _parse(0,@_) }
 
+sub _parse {
+
+   croak 'Usage: parse( \%defaults, \%user )' if scalar(@_) != 3;
+
+   my $casechk = shift;
    my $defaults = shift;
    croak ("First argument is not a hash reference")
       unless ref($defaults) eq "HASH";
@@ -100,7 +132,7 @@ sub parse {
 
    # Set up default behaviour
    $opt->minmatch(1);
-   $opt->casesens(1);
+   $opt->casesens($casechk);
    $opt->synonyms( \%DEF_SYNS );
 
    # Process the options
@@ -112,6 +144,15 @@ sub parse {
 
 =back
 
+=head2 Default Synonyms
+
+The following default synonyms are available in the non-OO interface:
+
+  COLOR  => COLOUR
+  COLOUR => COLOR
+  CENTER => CENTRE
+  CENTRE => CENTER
+
 =head1 METHODS
 
 The following methods are available to PDL::Options objects.
@@ -144,8 +185,11 @@ sub new {
   $opt->{AutoTranslate}= 1;# Automatically translate options when processing
   $opt->{MinMatchTrans} = 0; # Min matching during translation
   $opt->{CaseSensTrans} = 0; # Case sensitive during translation
-  $opt->{FullOptions} = 1; # Return full options list
-  $opt->{DEBUG}    = 0;    # Turn on debug messages
+  # Return full options list
+  $opt->{FullOptions} = $default->{FullOptions};
+  # Whether to warn for options that are invalid or not
+  $opt->{WarnOnMissing}= $default->{WarnOnMissing};
+  $opt->{DEBUG}    = $default->{DEBUG};    # Turn on debug messages
 
   # Bless into class
   bless ( $opt, $class);
@@ -156,6 +200,67 @@ sub new {
   return $opt;
 }
 
+=item extend (\%options)
+
+This will copy the existing options object and extend it with the
+requested extra options.
+
+=cut
+
+sub extend {
+
+  my ($self, $opt)=@_;
+
+  my $class = ref($self);
+  my $h = {%{$self}};
+  croak ("Argument is not reference to hash!\n") unless ref($opt) eq 'HASH';
+  #
+  # The next step is to perform a deep copy of the hash
+  # references since we might want to change these without
+  # changing the originals.
+  #
+  $h->{SYNONYMS}={%{$self->{SYNONYMS}}};
+  $h->{Translation}={%{$self->{Translation}}};
+  $h->{CurrKeys}=[@{$self->{CurrKeys}}];
+  #
+  # Create the extended option list.
+  #
+  my %all_options = (%{$opt}, %{$self->{DEFAULTS}});
+
+  # Bless it
+  bless ($h, $class);
+
+  # And parse the default options
+  $h->defaults(\%all_options);
+
+  return $h;
+
+}
+
+# =item change_defaults (\%options)
+
+# This will merge the options given with the defaults hash and hence change
+# the default hash. This is not normally a good idea, but in certain dynamic
+# situations you might want to adjust a default parameter for future calls
+# to the routine.
+
+# =cut
+
+# sub change_defaults {
+
+#   my $self=shift;
+
+#   my $arg = shift;
+#   croak("Argument is not a hash reference!\n") unless ref($arg) eq 'HASH';
+
+#   my $defs = $self->defaults($arg);
+
+#   $self->defaults($)
+
+
+# }
+
+
 =item defaults( \%defaults )
 
 Method to set or return the current defaults. The argument should be
@@ -188,6 +293,50 @@ sub defaults {
 
 }
 
+=item add_synonym (\%synonyms)
+
+Method to add another synonym to an option set
+The argument should be a reference to a hash.
+
+=cut
+
+sub add_synonym {
+  my $self=shift;
+  return unless @_;
+  my $arg = shift;
+  croak("Synonym argument is not a hash reference") unless ref($arg) eq "HASH";
+
+  foreach (keys %$arg) {
+    $self->{SYNONYMS}{$_}=$arg->{$_};
+  }
+  my %hash = %{$self->{SYNONYMS}};
+  return \%hash;
+
+}
+
+=item add_translation (\%translation)
+
+Method to add another translation rule to an option set.
+The argument should be a reference to a hash.
+
+=cut
+
+
+sub add_translation {
+  my $self = shift;
+  return unless @_;
+  my $arg = shift;
+  croak("Translation argument is not a hash reference") unless ref($arg) eq 'HASH';
+
+  foreach (keys %$arg) {
+    $self->{Translation}{$_}=$arg->{$_};
+  }
+  my %hash = %{$self->{Translation}};
+
+  return \%hash;
+
+}
+
 =item synonyms( \%synonyms )
 
 Method to set or return the current synonyms. The argument should be
@@ -244,6 +393,17 @@ sub current {
   }
 }
 
+=item clear_current
+
+This routine clears the 'state' of the C<PDL::Options> object so that
+the next call to current will return an empty list
+
+=cut
+
+sub clear_current {
+  my $self = shift;
+  @{$self->{CurrKeys}}=();
+}
 
 
 # Method to set the 'mini' state of the object
@@ -454,6 +614,27 @@ sub minmatchtrans {
 }
 
 
+=item warnonmissing
+
+Turn on or off the warning message printed when an options is not in
+the options hash. This can be convenient when a user passes a set of
+options that has to be parsed by several different option objects down
+the line.
+
+=cut
+
+sub warnonmissing {
+  my $self = shift;
+  if (ref $self) {
+    if (@_) { $self->{WarnOnMissing}=shift;}
+    return $self->{WarnOnMissing};
+  } else {
+    $default->{WarnOnMissing} = shift if @_;
+    return $default->{WarnOnMissing};
+  }
+}
+
+
 =item debug
 
 Turn on or off debug messages. Default is off (0).
@@ -463,8 +644,13 @@ Can be used to set or return this value.
 
 sub debug {
   my $self = shift;
-  if (@_) { $self->{DEBUG} = shift; }
-  return $self->{DEBUG};
+  if (ref $self) {
+    if (@_) { $self->{DEBUG} = shift; }
+    return $self->{DEBUG};
+  } else {
+    $default->{DEBUG} = shift if @_;
+    return $default->{DEBUG};
+  }
 }
 
 
@@ -479,7 +665,7 @@ Case sensitivity and minimum matching can be configured using
 the mimatch() and casesens() methods.
 
 A warning is raised if keys present in the user options are not
-present in the defaults.
+present in the defaults unless warnonmissing is set.
 
 A reference to a hash containing the merged options is returned.
 
@@ -548,7 +734,7 @@ sub options {
       # At this point we have matched the userkey to a key in the
       # defaults list (or if not say so)
       if ($#matched == -1) {
-	print "Warning: $userkey is not a valid option\n";
+	print "Warning: $userkey is not a valid option\n" if $self->{WarnOnMissing};
       } else {
 	if ( $#matched > 0 ) {
 	  print "Warning: Multiple matches for option $userkey\n";
@@ -704,8 +890,10 @@ sub compare_with_list {
 	# exact match even if alternatives exist (eg COL will always
 	# match just COL if the keys are COL and COLOUR)
 	# First do the exact match (case insensitive)
+      {
+	local $^W = undef; # To silence warnings about uninitialised values
 	@result =  grep { /^$key$/i } @list;
-
+      }
 	# If this match came up with something then we will use it
 	# Else we will try a minimum match (assuming flag is true)
 
@@ -742,7 +930,7 @@ the second uses the object-oriented interface.
 		  }
 		);
 
-This will return a hash containg
+This will return a hash containing
 
     %options = (
                  LINE => 1,
